diff --git a/src/backend/access/index/istrat.c b/src/backend/access/index/istrat.c
index 61cbe560656c36c54d593fd4944e3badae4c5424..268df6946e5868a5e9da8cb6235d9ed18d0a4a7b 100644
--- a/src/backend/access/index/istrat.c
+++ b/src/backend/access/index/istrat.c
@@ -8,7 +8,7 @@
  *
  *
  * IDENTIFICATION
- *	  $Header: /cvsroot/pgsql/src/backend/access/index/Attic/istrat.c,v 1.32 1999/05/25 16:07:15 momjian Exp $
+ *	  $Header: /cvsroot/pgsql/src/backend/access/index/Attic/istrat.c,v 1.33 1999/06/19 04:54:10 momjian Exp $
  *
  *-------------------------------------------------------------------------
  */
@@ -612,7 +612,7 @@ IndexSupportInitialize(IndexStrategy indexStrategy,
 			 attributeNumber++)
 		{
 			int16		support;
-			Form_pg_amproc form;
+			Form_pg_amproc aform;
 			RegProcedure *loc;
 
 			loc = &indexSupport[((attributeNumber - 1) * maxSupportNumber)];
@@ -627,8 +627,8 @@ IndexSupportInitialize(IndexStrategy indexStrategy,
 
 			while (HeapTupleIsValid(tuple = heap_getnext(scan, 0)))
 			{
-				form = (Form_pg_amproc) GETSTRUCT(tuple);
-				loc[(form->amprocnum - 1)] = form->amproc;
+				aform = (Form_pg_amproc) GETSTRUCT(tuple);
+				loc[(aform->amprocnum - 1)] = aform->amproc;
 			}
 
 			heap_endscan(scan);
@@ -667,12 +667,12 @@ IndexSupportInitialize(IndexStrategy indexStrategy,
 
 		while (HeapTupleIsValid(tuple = heap_getnext(scan, 0)))
 		{
-			Form_pg_amop form;
+			Form_pg_amop aform;
 
-			form = (Form_pg_amop) GETSTRUCT(tuple);
+			aform = (Form_pg_amop) GETSTRUCT(tuple);
 			OperatorRelationFillScanKeyEntry(operatorRelation,
-											 form->amopopr,
-					StrategyMapGetScanKeyEntry(map, form->amopstrategy));
+											 aform->amopopr,
+					StrategyMapGetScanKeyEntry(map, aform->amopstrategy));
 		}
 
 		heap_endscan(scan);
diff --git a/src/backend/catalog/index.c b/src/backend/catalog/index.c
index 37af4a4592ef1b34cec992eed7220fe211be5e0e..82689d1db13763f7e8de95136c424c2575e46259 100644
--- a/src/backend/catalog/index.c
+++ b/src/backend/catalog/index.c
@@ -7,7 +7,7 @@
  *
  *
  * IDENTIFICATION
- *	  $Header: /cvsroot/pgsql/src/backend/catalog/index.c,v 1.78 1999/06/16 11:01:17 momjian Exp $
+ *	  $Header: /cvsroot/pgsql/src/backend/catalog/index.c,v 1.79 1999/06/19 04:54:11 momjian Exp $
  *
  *
  * INTERFACE ROUTINES
@@ -372,7 +372,7 @@ AccessMethodObjectIdGetForm(Oid accessMethodObjectId)
 	HeapScanDesc pg_am_scan;
 	HeapTuple	pg_am_tuple;
 	ScanKeyData key;
-	Form_pg_am	form;
+	Form_pg_am	aform;
 
 	/* ----------------
 	 *	form a scan key for the pg_am relation
@@ -406,13 +406,13 @@ AccessMethodObjectIdGetForm(Oid accessMethodObjectId)
 	 *	if found am tuple, then copy the form and return the copy
 	 * ----------------
 	 */
-	form = (Form_pg_am) palloc(sizeof *form);
-	memcpy(form, GETSTRUCT(pg_am_tuple), sizeof *form);
+	aform = (Form_pg_am) palloc(sizeof *aform);
+	memcpy(aform, GETSTRUCT(pg_am_tuple), sizeof *aform);
 
 	heap_endscan(pg_am_scan);
 	heap_close(pg_am_desc);
 
-	return form;
+	return aform;
 }
 
 /* ----------------------------------------------------------------
diff --git a/src/backend/commands/command.c b/src/backend/commands/command.c
index c5785b737e0336a1dbd071069e75b0f782fe44cc..ebd4fd0c295d68cd498c3e111f34f7e15995c368 100644
--- a/src/backend/commands/command.c
+++ b/src/backend/commands/command.c
@@ -7,7 +7,7 @@
  *
  *
  * IDENTIFICATION
- *	  $Header: /cvsroot/pgsql/src/backend/commands/Attic/command.c,v 1.46 1999/05/25 22:40:54 momjian Exp $
+ *	  $Header: /cvsroot/pgsql/src/backend/commands/Attic/command.c,v 1.47 1999/06/19 04:54:12 momjian Exp $
  *
  * NOTES
  *	  The PortalExecutorHeapMemory crap needs to be eliminated
@@ -435,7 +435,7 @@ PerformAddAttribute(char *relationName,
 
 	{
 		HeapTuple	typeTuple;
-		Form_pg_type form;
+		Form_pg_type tform;
 		char	   *typename;
 		int			attnelems;
 
@@ -469,21 +469,21 @@ PerformAddAttribute(char *relationName,
 		typeTuple = SearchSysCacheTuple(TYPNAME,
 										PointerGetDatum(typename),
 										0, 0, 0);
-		form = (Form_pg_type) GETSTRUCT(typeTuple);
+		tform = (Form_pg_type) GETSTRUCT(typeTuple);
 
 		if (!HeapTupleIsValid(typeTuple))
 			elog(ERROR, "Add: type \"%s\" nonexistent", typename);
 		namestrcpy(&(attribute->attname), colDef->colname);
 		attribute->atttypid = typeTuple->t_data->t_oid;
-		attribute->attlen = form->typlen;
+		attribute->attlen = tform->typlen;
 		attribute->attdisbursion = 0;
 		attribute->attcacheoff = -1;
 		attribute->atttypmod = colDef->typename->typmod;
 		attribute->attnum = i;
-		attribute->attbyval = form->typbyval;
+		attribute->attbyval = tform->typbyval;
 		attribute->attnelems = attnelems;
-		attribute->attisset = (bool) (form->typtype == 'c');
-		attribute->attalign = form->typalign;
+		attribute->attisset = (bool) (tform->typtype == 'c');
+		attribute->attalign = tform->typalign;
 		attribute->attnotnull = false;
 		attribute->atthasdef = (colDef->defval != NULL);
 
diff --git a/src/backend/libpq/portalbuf.c b/src/backend/libpq/portalbuf.c
index 038a0a461412d817b6ec023df6f6de0939316df8..21cc62bcceb6405bfd770a72c3d8df418be82149 100644
--- a/src/backend/libpq/portalbuf.c
+++ b/src/backend/libpq/portalbuf.c
@@ -7,7 +7,7 @@
  *
  *
  * IDENTIFICATION
- *	  $Header: /cvsroot/pgsql/src/backend/libpq/Attic/portalbuf.c,v 1.14 1999/05/25 16:09:02 momjian Exp $
+ *	  $Header: /cvsroot/pgsql/src/backend/libpq/Attic/portalbuf.c,v 1.15 1999/06/19 04:54:13 momjian Exp $
  *
  *-------------------------------------------------------------------------
  */
@@ -89,7 +89,7 @@ portals_realloc(size_t size)
 		portals = newp;
 	else
 		libpq_raise(&PortalError,
-					form("Cannot alloc more memory in portals_realloc"));
+					varargform("Cannot alloc more memory in portals_realloc"));
 
 	for (i = oldsize; i < portals_array_size; i++)
 		portals[i] = (PortalEntry *) NULL;
@@ -109,11 +109,11 @@ pbuf_alloc(size_t size)
 	caddr_t		addr;
 
 	if (size <= 0)
-		libpq_raise(&MemoryError, form("Invalid argument to pbuf_alloc()."));
+		libpq_raise(&MemoryError, varargform("Invalid argument to pbuf_alloc()."));
 
 	addr = (caddr_t) palloc(size);
 	if (addr == (caddr_t) NULL)
-		libpq_raise(&MemoryError, form("Cannot Allocate space."));
+		libpq_raise(&MemoryError, varargform("Cannot Allocate space."));
 
 	return addr;
 }
@@ -131,7 +131,7 @@ pbuf_free(caddr_t pointer)
 	if (pointer)
 		pfree(pointer);
 	else
-		libpq_raise(&MemoryError, form("Tried to free NULL memory pointer"));
+		libpq_raise(&MemoryError, varargform("Tried to free NULL memory pointer"));
 
 }
 
@@ -437,7 +437,7 @@ pbuf_close(char *pname)
 	int			i;
 
 	if ((i = pbuf_getIndex(pname)) == -1)
-		libpq_raise(&PortalError, form("Portal %s does not exist.", pname));
+		libpq_raise(&PortalError, varargform("Portal %s does not exist.", pname));
 
 	pbuf_freePortal(portals[i]->portal);
 	pbuf_freeEntry(i);
@@ -462,7 +462,7 @@ pbuf_findGroup(PortalBuffer *portal,
 
 	if (group == NULL)
 		libpq_raise(&PortalError,
-					form("Group index %d out of bound.", group_index));
+					varargform("Group index %d out of bound.", group_index));
 
 	return group;
 }
@@ -485,7 +485,7 @@ pbuf_findFnumber(GroupBuffer *group,
 			return i;
 
 	libpq_raise(&PortalError,
-				form("Field-name %s does not exist.", field_name));
+				varargform("Field-name %s does not exist.", field_name));
 
 	/* not reached, here to make compiler happy */
 	return 0;
@@ -502,7 +502,7 @@ pbuf_checkFnumber(GroupBuffer *group,
 {
 	if (field_number < 0 || field_number >= group->no_fields)
 		libpq_raise(&PortalError,
-					form("Field number %d out of bound.", field_number));
+					varargform("Field number %d out of bound.", field_number));
 }
 
 /* --------------------------------
diff --git a/src/backend/optimizer/path/indxpath.c b/src/backend/optimizer/path/indxpath.c
index 4a2dbbb0fe5dac186d1f8daf75a86daaa2eab676..e1870912bffeebb604b15dcb49480d292091dda8 100644
--- a/src/backend/optimizer/path/indxpath.c
+++ b/src/backend/optimizer/path/indxpath.c
@@ -8,7 +8,7 @@
  *
  *
  * IDENTIFICATION
- *	  $Header: /cvsroot/pgsql/src/backend/optimizer/path/indxpath.c,v 1.56 1999/05/25 22:41:28 momjian Exp $
+ *	  $Header: /cvsroot/pgsql/src/backend/optimizer/path/indxpath.c,v 1.57 1999/06/19 04:54:14 momjian Exp $
  *
  *-------------------------------------------------------------------------
  */
@@ -1008,7 +1008,7 @@ clause_pred_clause_test(Expr *predicate, Node *clause)
 	HeapScanDesc scan;
 	HeapTuple	tuple;
 	ScanKeyData entry[3];
-	Form_pg_amop form;
+	Form_pg_amop aform;
 
 	pred_var = (Var *) get_leftop(predicate);
 	pred_const = (Const *) get_rightop(predicate);
@@ -1067,13 +1067,13 @@ clause_pred_clause_test(Expr *predicate, Node *clause)
 		elog(DEBUG, "clause_pred_clause_test: unknown pred_op");
 		return false;
 	}
-	form = (Form_pg_amop) GETSTRUCT(tuple);
+	aform = (Form_pg_amop) GETSTRUCT(tuple);
 
 	/* Get the predicate operator's strategy number (1 to 5) */
-	pred_strategy = (StrategyNumber) form->amopstrategy;
+	pred_strategy = (StrategyNumber) aform->amopstrategy;
 
 	/* Remember which operator class this strategy number came from */
-	opclass_id = form->amopclaid;
+	opclass_id = aform->amopclaid;
 
 	heap_endscan(scan);
 
@@ -1098,10 +1098,10 @@ clause_pred_clause_test(Expr *predicate, Node *clause)
 		elog(DEBUG, "clause_pred_clause_test: unknown clause_op");
 		return false;
 	}
-	form = (Form_pg_amop) GETSTRUCT(tuple);
+	aform = (Form_pg_amop) GETSTRUCT(tuple);
 
 	/* Get the restriction clause operator's strategy number (1 to 5) */
-	clause_strategy = (StrategyNumber) form->amopstrategy;
+	clause_strategy = (StrategyNumber) aform->amopstrategy;
 	heap_endscan(scan);
 
 
@@ -1130,10 +1130,10 @@ clause_pred_clause_test(Expr *predicate, Node *clause)
 		elog(DEBUG, "clause_pred_clause_test: unknown test_op");
 		return false;
 	}
-	form = (Form_pg_amop) GETSTRUCT(tuple);
+	aform = (Form_pg_amop) GETSTRUCT(tuple);
 
 	/* Get the test operator */
-	test_op = form->amopopr;
+	test_op = aform->amopopr;
 	heap_endscan(scan);
 
 
diff --git a/src/backend/utils/error/format.c b/src/backend/utils/error/format.c
index f56e3f05b31263c350f5976097932329709c8b41..7cf8f3b030e6a4206e0c1b4418ad38e8ff918d37 100644
--- a/src/backend/utils/error/format.c
+++ b/src/backend/utils/error/format.c
@@ -7,7 +7,7 @@
  *
  *
  * IDENTIFICATION
- *	  $Header: /cvsroot/pgsql/src/backend/utils/error/Attic/format.c,v 1.11 1999/05/25 16:12:26 momjian Exp $
+ *	  $Header: /cvsroot/pgsql/src/backend/utils/error/Attic/format.c,v 1.12 1999/06/19 04:54:19 momjian Exp $
  *
  *-------------------------------------------------------------------------
  */
@@ -22,11 +22,11 @@ static char FormBuf[FormMaxSize];
 
 
 /* ----------------
- *		form
+ *		varargform
  * ----------------
  */
 char *
-form(const char *fmt,...)
+varargform(const char *fmt,...)
 {
 	va_list		args;
 
diff --git a/src/backend/utils/mmgr/portalmem.c b/src/backend/utils/mmgr/portalmem.c
index f02a09232ff612fa652b43492fa45d6ddcb18beb..84818e8b35ef032816346f23b5c2442304256cec 100644
--- a/src/backend/utils/mmgr/portalmem.c
+++ b/src/backend/utils/mmgr/portalmem.c
@@ -7,7 +7,7 @@
  *
  *
  * IDENTIFICATION
- *	  $Header: /cvsroot/pgsql/src/backend/utils/mmgr/portalmem.c,v 1.21 1999/06/12 14:07:26 momjian Exp $
+ *	  $Header: /cvsroot/pgsql/src/backend/utils/mmgr/portalmem.c,v 1.22 1999/06/19 04:54:19 momjian Exp $
  *
  *-------------------------------------------------------------------------
  */
@@ -234,7 +234,7 @@ PortalVariableMemoryRealloc(PortalVariableMemory this,
 static char *
 PortalVariableMemoryGetName(PortalVariableMemory this)
 {
-	return form("%s-var", PortalVariableMemoryGetPortal(this)->name);
+	return varargform("%s-var", PortalVariableMemoryGetPortal(this)->name);
 }
 
 /* ----------------
@@ -312,7 +312,7 @@ PortalHeapMemoryRealloc(PortalHeapMemory this,
 static char *
 PortalHeapMemoryGetName(PortalHeapMemory this)
 {
-	return form("%s-heap", PortalHeapMemoryGetPortal(this)->name);
+	return varargform("%s-heap", PortalHeapMemoryGetPortal(this)->name);
 }
 
 /* ----------------
diff --git a/src/include/c.h b/src/include/c.h
index 4b7f7aa03d923f557d6d0118cf62b57e76cd5e3c..175683a500811cb4570cd50cbb27404b32a610dd 100644
--- a/src/include/c.h
+++ b/src/include/c.h
@@ -7,7 +7,7 @@
  *
  * Copyright (c) 1994, Regents of the University of California
  *
- * $Id: c.h,v 1.55 1999/05/25 16:13:22 momjian Exp $
+ * $Id: c.h,v 1.56 1999/06/19 04:54:23 momjian Exp $
  *
  *-------------------------------------------------------------------------
  */
@@ -591,7 +591,7 @@ extern int	assert_enabled;
 #define LogTrap(condition, exception, printArgs) \
 		{ if ((assert_enabled) && (condition)) \
 				ExceptionalCondition(CppAsString(condition), &(exception), \
-						form printArgs, __FILE__, __LINE__); }
+						varargform printArgs, __FILE__, __LINE__); }
 
 /*
  *	LogTrapMacro is the same as LogTrap but it's intended for use in macros:
@@ -602,7 +602,7 @@ extern int	assert_enabled;
 	((bool) ((! assert_enabled) || (! condition) || \
 			 (ExceptionalCondition(CppAsString(condition), \
 								   &(exception), \
-								   form printArgs, __FILE__, __LINE__))))
+								   varargform printArgs, __FILE__, __LINE__))))
 
 #ifndef USE_ASSERT_CHECKING
 #define LogAssert(condition, printArgs)
@@ -711,10 +711,10 @@ extern int ExceptionalCondition(char *conditionName,
 
 
 /* ----------------
  *		form is used by assert and the exception handling stuff
  * ----------------
  */
-extern char *form(const char *fmt,...);
+extern char *varargform(const char *fmt,...);
@@ -711,10 +711,10 @@ extern int ExceptionalCondition(char *conditionName,
 
 /* ----------------
- *		form is used by assert and the exception handling stuff
+ *		varargform is used by assert and the exception handling stuff
  * ----------------
  */